@@ -88,8 +88,8 @@ pub fn populate_base_models(store: &impl Storelike) -> AtomicResult<()> {
     store.add_resource_unsafe(&requires)?;
 
     let property = Class {
-        requires: vec![urls::SHORTNAME.into()],
-        recommends: vec![],
+        requires: vec![urls::SHORTNAME.into(), urls::DATATYPE_PROP.into()],
+        recommends: vec![urls::DESCRIPTION.into(), urls::CLASSTYPE_PROP.into(), urls::IS_DYNAMIC.into(), urls::IS_LOCKED.into()],
         shortname: "property".into(),
         description: "A Property is a single field in a Class. It's the thing that a property field in an Atom points to. An example is `birthdate`. An instance of Property requires various Properties, most notably a `datatype` (e.g. `string` or `integer`), a human readable `description` (such as the thing you're reading), and a `shortname`.".into(),
         subject: urls::PROPERTY.into(),
