@@ -1,7 +1,7 @@
 //! Helper functions for dealing with URLs
 
-use url::Url;
 use crate::errors::AtomicResult;
+use url::Url;
 
 pub fn base_url(url: &str) -> AtomicResult<String> {
     let mut parsed: Url = Url::parse(url)?;
@@ -10,9 +10,7 @@ pub fn base_url(url: &str) -> AtomicResult<String> {
         Ok(mut path) => {
             path.clear();
         }
-        Err(_) => {
-            return Err(format!("Url {} is not valid.", url).into())
-        }
+        Err(_) => return Err(format!("Url {} is not valid.", url).into()),
     }
 
     parsed.set_query(None);
@@ -22,8 +20,8 @@ pub fn base_url(url: &str) -> AtomicResult<String> {
 
 /// Throws an error if the URL is not a valid URL
 pub fn check_valid_url(url: &str) -> AtomicResult<()> {
-     if !url.starts_with("http") {
-         return Err(format!("Url does not start with http: {}", url).into())
-     }
-     Ok(())
+    if !url.starts_with("http") {
+        return Err(format!("Url does not start with http: {}", url).into());
+    }
+    Ok(())
 }
