@@ -1,6 +1,9 @@
 //! A value is the part of an Atom that contains the actual information.
 
-use crate::{datatype::DataType, datatype::match_datatype, errors::AtomicResult, resources::PropVals, url_helpers::check_valid_url};
+use crate::{
+    datatype::match_datatype, datatype::DataType, errors::AtomicResult, resources::PropVals,
+    url_helpers::check_valid_url,
+};
 use regex::Regex;
 use serde::{Deserialize, Serialize};
 
@@ -83,7 +86,7 @@ impl Value {
             DataType::AtomicUrl => {
                 check_valid_url(value)?;
                 Ok(Value::AtomicUrl(value.into()))
-            },
+            }
             DataType::ResourceArray => {
                 let vector: Vec<String> = crate::parse::parse_json_array(&value).map_err(|e| {
                     return format!("Could not deserialize ResourceArray: {}. Should be a JSON array of strings. {}", &value, e);
@@ -244,7 +247,7 @@ mod test {
         assert!(date.to_string() == "1200-02-02");
         let date = Value::new("1.123123", &DataType::Float).unwrap();
         assert!(date.to_string() == "1.123123");
-        let converted  = Value::from(8);
+        let converted = Value::from(8);
         assert!(converted.to_string() == "8");
     }
 
